package fr.openium.consentium.ui.navigation

import Destination
import androidx.compose.animation.core.tween
import androidx.compose.animation.slideIn
import androidx.compose.animation.slideOut
import androidx.compose.runtime.Composable
import androidx.compose.ui.unit.IntOffset
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import fr.openium.consentium.ui.screens.main.MainScreen
import fr.openium.consentium.ui.screens.splash.SplashScreen

private const val NAV_ANIMATION_TIME = 500

@Composable
fun DemoNavGraph(navHostController: NavHostController) {

    NavHost(
        navController = navHostController,
        startDestination = Destination.Splash,
        enterTransition = {
            slideIn(
                animationSpec = tween(NAV_ANIMATION_TIME),
                initialOffset = { fullSize -> IntOffset(x = fullSize.height, y = 0) }
            )
        },
        exitTransition = {
            slideOut(
                animationSpec = tween(NAV_ANIMATION_TIME),
                targetOffset = { fullSize -> IntOffset(x = -fullSize.height, y = 0) }
            )
        },
    ) {

        composable<Destination.Splash> {
            SplashScreen(
                navigateToMain = {
                    navHostController.navigate(Destination.Main) {
                        popUpTo(navHostController.graph.findStartDestination().id) {
                            saveState = true
                        }
                    }
                }
            )
        }

        composable<Destination.Main> {
            MainScreen(
                onGoToConsentDetail = {
                    navHostController.navigate(Destination.Consent)
                },
                onGoToConsentMaster = {
                    navHostController.navigate(Destination.Consent)
                }
            )
        }

        composable<Destination.Consent> {
            // TODO
        }
    }
}
