package fr.openium.consentium.ui.screens.splash

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.size
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel

@Composable
fun SplashScreen(
    navigateToMain: () -> Unit,
    viewModel: SplashScreenViewModel = hiltViewModel(),
) {
    // State
    val currentState by viewModel.state.collectAsState()

    // Effect
    LaunchedEffect(Unit) {
        viewModel.initMain()
    }

    LaunchedEffect(currentState) {
        when (val state = currentState) {
            is SplashScreenViewModel.State.Loaded -> {
                if (state.isSplashEnded) {
                    navigateToMain()
                }
            }
        }
    }

    // View
    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {

        Text("Splash Screen")

        Spacer(modifier = Modifier.height(14.dp))

        CircularProgressIndicator(
            modifier = Modifier.size(40.dp)
        )

    }

}